@@ -1,6 +1,6 @@
-from .common import S3Artifact
-from .dag import DAG
+from .common import LocalArtifact, S3Artifact
 from .context import Context
+from .dag import DAG
 from .executor import Executor, RemoteExecutor
 from .io import (AutonamedDict, IfExpression, InputArtifact, InputParameter,
                  Inputs, OutputArtifact, OutputParameter, Outputs,
@@ -12,8 +12,8 @@ from .step import Step, argo_len, argo_range, argo_sequence
 from .steps import Steps
 from .task import Task
 from .utils import (copy_artifact, copy_s3, download_artifact, download_s3,
-                    path_list_of_artifact, s3_config, upload_artifact,
-                    upload_s3, randstr)
+                    path_list_of_artifact, randstr, s3_config, upload_artifact,
+                    upload_s3)
 from .workflow import Workflow, config
 
 __all__ = ["S3Artifact", "DAG", "Executor", "RemoteExecutor", "AutonamedDict",
@@ -25,4 +25,4 @@ __all__ = ["S3Artifact", "DAG", "Executor", "RemoteExecutor", "AutonamedDict",
            "argo_sequence", "Steps", "Task", "copy_artifact", "copy_s3",
            "download_artifact", "download_s3", "path_list_of_artifact",
            "s3_config", "upload_artifact", "upload_s3", "Workflow", "config",
-           "Context", "randstr"]
+           "Context", "randstr", "LocalArtifact"]
