@@ -164,22 +164,21 @@ class IfExpression:
             _then: Union[str, ArgoVar],
             _else: Union[str, ArgoVar],
     ) -> None:
-        self._if = _if
+        if isinstance(_if, (InputParameter, OutputParameter)):
+            self._if = "%s == 'true'" % _if.expr
+        elif isinstance(_if, ArgoVar):
+            self._if = _if.expr
+        else:
+            self._if = _if
         self._then = _then
         self._else = _else
 
     def __repr__(self) -> str:
-        if isinstance(self._if, (InputParameter, OutputParameter)):
-            _if = "%s == 'true'" % self._if.expr
-        elif isinstance(self._if, ArgoVar):
-            _if = self._if.expr
-        else:
-            _if = self._if
         _then = self._then.expr if isinstance(
             self._then, ArgoVar) else self._then
         _else = self._else.expr if isinstance(
             self._else, ArgoVar) else self._else
-        return "%s ? %s : %s" % (_if, _then, _else)
+        return "%s ? %s : %s" % (self._if, _then, _else)
 
 
 def if_expression(
@@ -246,15 +245,18 @@ class InputParameter(ArgoVar):
         if "value" in kwargs:
             self.value = kwargs["value"]
         self.save_as_artifact = save_as_artifact
+        if config["mode"] == "debug":
+            self.save_as_artifact = False
         self.path = path
         self.source = source
 
     def __getattr__(self, key):
+        from .task import Task
         if key == "expr":
             if self.save_as_artifact:
                 if self.name is not None:
                     if self.step is not None:
-                        if hasattr(self.step, "is_task"):
+                        if isinstance(self.step, Task):
                             return "tasks['%s'].inputs.artifacts"\
                                 "['dflow_bigpar_%s']" % (
                                     self.step.id, self.name)
@@ -266,7 +268,7 @@ class InputParameter(ArgoVar):
                 return ""
             if self.name is not None:
                 if self.step is not None:
-                    if hasattr(self.step, "is_task"):
+                    if isinstance(self.step, Task):
                         return "tasks['%s'].inputs.parameters['%s']" % \
                             (self.step.id, self.name)
                     else:
@@ -277,10 +279,11 @@ class InputParameter(ArgoVar):
         return super().__getattr__(key)
 
     def __repr__(self):
+        from .task import Task
         if self.save_as_artifact:
             if self.name is not None:
                 if self.step is not None:
-                    if hasattr(self.step, "is_task"):
+                    if isinstance(self.step, Task):
                         return "{{tasks.%s.inputs.artifacts.dflow_bigpar_%s}}"\
                             % (self.step.id, self.name)
                     else:
@@ -290,7 +293,7 @@ class InputParameter(ArgoVar):
             return ""
         if self.name is not None:
             if self.step is not None:
-                if hasattr(self.step, "is_task"):
+                if isinstance(self.step, Task):
                     return "{{tasks.%s.inputs.parameters.%s}}" % (self.step.id,
                                                                   self.name)
                 else:
@@ -388,10 +391,11 @@ class InputArtifact(ArgoVar):
         self.sub_path = sub_path
 
     def __getattr__(self, key):
+        from .task import Task
         if key == "expr":
             if self.name is not None:
                 if self.step is not None:
-                    if hasattr(self.step, "is_task"):
+                    if isinstance(self.step, Task):
                         return "tasks['%s'].inputs.artifacts['%s']" % \
                             (self.step.id, self.name)
                     else:
@@ -402,9 +406,10 @@ class InputArtifact(ArgoVar):
         return super().__getattr__(key)
 
     def __repr__(self):
+        from .task import Task
         if self.name is not None:
             if self.step is not None:
-                if hasattr(self.step, "is_task"):
+                if isinstance(self.step, Task):
                     return "{{tasks.%s.inputs.artifacts.%s}}" % (self.step.id,
                                                                  self.name)
                 else:
@@ -488,6 +493,8 @@ class OutputParameter(ArgoVar):
         self.global_name = global_name
         self.value_from_expression = value_from_expression
         self.save_as_artifact = save_as_artifact
+        if config["mode"] == "debug":
+            self.save_as_artifact = False
         if "default" in kwargs:
             self.default = kwargs["default"]
         if "value" in kwargs:
@@ -495,11 +502,12 @@ class OutputParameter(ArgoVar):
         self.value_from_parameter = value_from_parameter
 
     def __getattr__(self, key):
+        from .task import Task
         if key == "expr":
             if self.save_as_artifact:
                 if self.name is not None:
                     if self.step is not None:
-                        if hasattr(self.step, "is_task"):
+                        if isinstance(self.step, Task):
                             return "tasks['%s'].outputs.artifacts"\
                                 "['dflow_bigpar_%s']" % (
                                     self.step.id, self.name)
@@ -510,7 +518,7 @@ class OutputParameter(ArgoVar):
                     return "outputs.artifacts['dflow_bigpar_%s']" % self.name
             if self.name is not None:
                 if self.step is not None:
-                    if hasattr(self.step, "is_task"):
+                    if isinstance(self.step, Task):
                         return "tasks['%s'].outputs.parameters['%s']" % \
                             (self.step.id, self.name)
                     else:
@@ -554,10 +562,11 @@ class OutputParameter(ArgoVar):
         return super().__setattr__(key, value)
 
     def __repr__(self):
+        from .task import Task
         if self.save_as_artifact:
             if self.name is not None:
                 if self.step is not None:
-                    if hasattr(self.step, "is_task"):
+                    if isinstance(self.step, Task):
                         return \
                             "{{tasks.%s.outputs.artifacts.dflow_bigpar_%s}}" \
                             % (self.step.id, self.name)
@@ -568,7 +577,7 @@ class OutputParameter(ArgoVar):
                 return "{{outputs.artifacts.dflow_bigpar_%s}}" % self.name
         if self.name is not None:
             if self.step is not None:
-                if hasattr(self.step, "is_task"):
+                if isinstance(self.step, Task):
                     return "{{tasks.%s.outputs.parameters.%s}}" % (
                         self.step.id, self.name)
                 else:
@@ -700,6 +709,7 @@ class OutputArtifact(ArgoVar):
         return artifact
 
     def __getattr__(self, key):
+        from .task import Task
         if key == "expr":
             if self.redirect is not None:
                 return self.redirect.expr
@@ -707,7 +717,7 @@ class OutputArtifact(ArgoVar):
                 return "workflow.outputs.artifacts['%s']" % (self.global_name)
             elif self.name is not None:
                 if self.step is not None:
-                    if hasattr(self.step, "is_task"):
+                    if isinstance(self.step, Task):
                         return "tasks['%s'].outputs.artifacts['%s']" % (
                             self.step.id, self.name)
                     else:
@@ -747,13 +757,14 @@ class OutputArtifact(ArgoVar):
         return self.step.outputs.parameters["dflow_%s_path_list" % self.name]
 
     def __repr__(self):
+        from .task import Task
         if self.redirect is not None:
             return str(self.redirect)
         if self.global_name is not None:
             return "{{workflow.outputs.artifacts.%s}}" % (self.global_name)
         elif self.name is not None:
             if self.step is not None:
-                if hasattr(self.step, "is_task"):
+                if isinstance(self.step, Task):
                     return "{{tasks.%s.outputs.artifacts.%s}}" % (self.step.id,
                                                                   self.name)
                 else:
