@@ -1,6 +1,7 @@
 from typing import Dict, List, Union
 
-from .io import PVC, InputParameter, Inputs, Outputs
+from .config import config as global_config
+from .io import PVC, InputParameter, Inputs, OutputParameter, Outputs
 from .utils import randstr
 
 try:
@@ -11,7 +12,7 @@ try:
                                        V1alpha1Template,
                                        V1ConfigMapKeySelector, V1EnvVar,
                                        V1ResourceRequirements, V1Volume,
-                                       V1VolumeMount)
+                                       V1VolumeMount, V1alpha1UserContainer)
     from argo.workflows.client.configuration import Configuration
 
     from .client.v1alpha1_retry_strategy import V1alpha1RetryStrategy
@@ -20,6 +21,7 @@ except Exception:
     V1alpha1RetryStrategy = object
     V1Volume = object
     V1VolumeMount = object
+    V1alpha1UserContainer = object
 
 
 class OPTemplate:
@@ -69,6 +71,19 @@ class OPTemplate:
                 self.memoize_key = "%s-{{inputs.parameters.dflow_key}}" \
                     % memoize_prefix
 
+            if global_config["save_keys_in_global_outputs"]:
+                if hasattr(self, "image"):
+                    self.outputs.parameters["dflow_global"] = OutputParameter(
+                        value="{}",
+                        global_name="{{inputs.parameters.dflow_key}}",
+                    )
+                else:
+                    self.outputs.parameters["dflow_global"] = OutputParameter(
+                        value_from_parameter="non-exists",
+                        default="{}",
+                        global_name="{{inputs.parameters.dflow_key}}",
+                    )
+
         if self.memoize_key is not None:
             # Is it a bug of Argo?
             if self.memoize_key.find("workflow.name") != -1:
@@ -132,6 +147,7 @@ class ScriptOPTemplate(OPTemplate):
             requests: Dict[str, str] = None,
             limits: Dict[str, str] = None,
             envs: Dict[str, str] = None,
+            init_containers: List[V1alpha1UserContainer] = None,
             **kwargs,
     ) -> None:
         super().__init__(name=name, inputs=inputs, outputs=outputs,
@@ -156,6 +172,7 @@ class ScriptOPTemplate(OPTemplate):
         self.requests = requests
         self.limits = limits
         self.envs = envs
+        self.init_containers = init_containers
 
     def convert_to_argo(self, memoize_prefix=None,
                         memoize_configmap="dflow"):
@@ -171,7 +188,9 @@ class ScriptOPTemplate(OPTemplate):
                                     retry_strategy=self.retry_strategy,
                                     memoize=self.memoize,
                                     volumes=self.volumes,
-                                    resource=self.resource)
+                                    resource=self.resource,
+                                    init_containers=self.init_containers,
+                                    )
         else:
             if self.envs is not None:
                 env = [V1EnvVar(name=k, value=v) for k, v in self.envs.items()]
@@ -195,7 +214,9 @@ class ScriptOPTemplate(OPTemplate):
                                      resources=V1ResourceRequirements(
                                          limits=self.limits,
                                          requests=self.requests),
-                                     env=env))
+                                     env=env),
+                                 init_containers=self.init_containers,
+                                 )
 
 
 class ShellOPTemplate(ScriptOPTemplate):
@@ -221,6 +242,7 @@ class ShellOPTemplate(ScriptOPTemplate):
         requests: a dict of resource requests
         limits: a dict of resource limits
         envs: environment variables
+        init_containers: init containers before the template runs
     """
 
     def __init__(
@@ -243,6 +265,7 @@ class ShellOPTemplate(ScriptOPTemplate):
         requests: Dict[str, str] = None,
         limits: Dict[str, str] = None,
         envs: Dict[str, str] = None,
+        init_containers: List[V1alpha1UserContainer] = None,
         **kwargs,
     ) -> None:
         if command is None:
@@ -253,7 +276,9 @@ class ShellOPTemplate(ScriptOPTemplate):
             init_progress=init_progress, timeout=timeout,
             retry_strategy=retry_strategy, memoize_key=memoize_key, pvcs=pvcs,
             image_pull_policy=image_pull_policy, annotations=annotations,
-            requests=requests, limits=limits, envs=envs)
+            requests=requests, limits=limits, envs=envs,
+            init_containers=init_containers,
+        )
 
 
 class PythonScriptOPTemplate(ScriptOPTemplate):
@@ -279,6 +304,7 @@ class PythonScriptOPTemplate(ScriptOPTemplate):
         requests: a dict of resource requests
         limits: a dict of resource limits
         envs: environment variables
+        init_containers: init containers before the template runs
     """
 
     def __init__(
@@ -301,6 +327,7 @@ class PythonScriptOPTemplate(ScriptOPTemplate):
         requests: Dict[str, str] = None,
         limits: Dict[str, str] = None,
         envs: Dict[str, str] = None,
+        init_containers: List[V1alpha1UserContainer] = None,
         **kwargs,
     ) -> None:
         if command is None:
@@ -311,4 +338,6 @@ class PythonScriptOPTemplate(ScriptOPTemplate):
             init_progress=init_progress, timeout=timeout,
             retry_strategy=retry_strategy, memoize_key=memoize_key, pvcs=pvcs,
             image_pull_policy=image_pull_policy, annotations=annotations,
-            requests=requests, limits=limits, envs=envs)
+            requests=requests, limits=limits, envs=envs,
+            init_containers=init_containers,
+        )
